Quantum states and ensembles
============================

.. toctree::

.. autosummary::
    :toctree: _autosummary

    qustop.State
    qustop.Ensemble

Optimal quantum state discrimination
=====================================

.. toctree::

.. autosummary::
    :toctree: _autosummary

    qustop.OptDist
    qustop.Positive
    qustop.PPT
    qustop.Separable

Optimal quantum state exclusion
================================

.. toctree::

.. autosummary::
    :toctree: _autosummary

    qustop.OptExclude

Optimal quantum state cloning
=============================

.. toctree::

.. autosummary::
    :toctree: _autosummary

    qustop.OptClone